From mboxrd@z Thu Jan  1 00:00:00 1970
Return-Path: <dev-bounces@dpdk.org>
Received: from mails.dpdk.org (mails.dpdk.org [217.70.189.124])
	by inbox.dpdk.org (Postfix) with ESMTP id 39BB943329;
	Tue, 14 Nov 2023 12:11:00 +0100 (CET)
Received: from mails.dpdk.org (localhost [127.0.0.1])
	by mails.dpdk.org (Postfix) with ESMTP id D033B40A81;
	Tue, 14 Nov 2023 12:10:09 +0100 (CET)
Received: from szxga01-in.huawei.com (szxga01-in.huawei.com [45.249.212.187])
 by mails.dpdk.org (Postfix) with ESMTP id 27715402E4
 for <dev@dpdk.org>; Tue, 14 Nov 2023 12:09:58 +0100 (CET)
Received: from kwepemd100004.china.huawei.com (unknown [172.30.72.53])
 by szxga01-in.huawei.com (SkyGuard) with ESMTP id 4SV3Tx3V16zvQZH;
 Tue, 14 Nov 2023 19:09:41 +0800 (CST)
Received: from localhost.localdomain (10.67.165.2) by
 kwepemd100004.china.huawei.com (7.221.188.31) with Microsoft SMTP Server
 (version=TLS1_2, cipher=TLS_ECDHE_RSA_WITH_AES_128_GCM_SHA256) id
 15.2.1258.23; Tue, 14 Nov 2023 19:09:56 +0800
From: Jie Hai <haijie1@huawei.com>
To: <dev@dpdk.org>, Anatoly Burakov <anatoly.burakov@intel.com>, Amit Prakash
 Shukla <amitprakashs@marvell.com>
CC: <haijie1@huawei.com>, <lihuisong@huawei.com>, <fengchengwen@huawei.com>
Subject: [PATCH v3 10/22] eal: replace strtok with reentrant version
Date: Tue, 14 Nov 2023 18:59:54 +0800
Message-ID: <20231114110006.91148-11-haijie1@huawei.com>
X-Mailer: git-send-email 2.30.0
In-Reply-To: <20231114110006.91148-1-haijie1@huawei.com>
References: <20231113104550.2138654-1-haijie1@huawei.com>
 <20231114110006.91148-1-haijie1@huawei.com>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit
Content-Type: text/plain
X-Originating-IP: [10.67.165.2]
X-ClientProxiedBy: dggems705-chm.china.huawei.com (10.3.19.182) To
 kwepemd100004.china.huawei.com (7.221.188.31)
X-CFilter-Loop: Reflected
X-BeenThere: dev@dpdk.org
X-Mailman-Version: 2.1.29
Precedence: list
List-Id: DPDK patches and discussions <dev.dpdk.org>
List-Unsubscribe: <https://mails.dpdk.org/options/dev>,
 <mailto:dev-request@dpdk.org?subject=unsubscribe>
List-Archive: <http://mails.dpdk.org/archives/dev/>
List-Post: <mailto:dev@dpdk.org>
List-Help: <mailto:dev-request@dpdk.org?subject=help>
List-Subscribe: <https://mails.dpdk.org/listinfo/dev>,
 <mailto:dev-request@dpdk.org?subject=subscribe>
Errors-To: dev-bounces@dpdk.org

Multiple threads calling the same function may cause condition
race issues, which often leads to abnormal behavior and can cause
more serious vulnerabilities such as abnormal termination, denial
of service, and compromised data integrity.

The strtok() is non-reentrant, it is better to replace it with a
reentrant version.

Fixes: 2054f31a1fcd ("mem: add memseg info in telemetry")
Cc: stable@dpdk.org

Signed-off-by: Jie Hai <haijie1@huawei.com>
Acked-by: Chengwen Feng <fengchengwen@huawei.com>
---
 lib/eal/common/eal_common_memory.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/eal/common/eal_common_memory.c b/lib/eal/common/eal_common_memory.c
index d9433db62345..a05eb0442b0b 100644
--- a/lib/eal/common/eal_common_memory.c
+++ b/lib/eal/common/eal_common_memory.c
@@ -1273,22 +1273,22 @@ parse_params(const char *params, uint32_t *vals, size_t n_vals)
 	char dlim[2] = ",";
 	char *params_args;
 	size_t count = 0;
-	char *token;
+	char *token, *sp = NULL;
 
 	if (vals == NULL || params == NULL || strlen(params) == 0)
 		return -1;
 
 	/* strtok expects char * and param is const char *. Hence on using
 	 * params as "const char *" compiler throws warning.
 	 */
 	params_args = strdup(params);
 	if (params_args == NULL)
 		return -1;
 
-	token = strtok(params_args, dlim);
+	token = strtok_r(params_args, dlim, &sp);
 	while (token && isdigit(*token) && count < n_vals) {
 		vals[count++] = strtoul(token, NULL, 10);
-		token = strtok(NULL, dlim);
+		token = strtok_r(NULL, dlim, &sp);
 	}
 
 	free(params_args);
@@ -1273,22 +1273,22 @@ parse_params(const char *params, uint32_t *vals, size_t n_vals)
 		return -1;
 
-	/* strtok expects char * and param is const char *. Hence on using
+	/* strtok_r expects char * and param is const char *. Hence on using
 	 * params as "const char *" compiler throws warning.
 	 */
-- 
2.30.0